# coding=utf-8
import logging
import traceback

import timeout_decorator
from django_cron import CronJobBase, Schedule

from web.models import ConfigurationItem
from web.models.constants import CRON_JOB_TIMEOUT, DEFAULT_FROM_EMAIL, DAILY_SUBJECT_EXPORT_FILE, \
    DAILY_VISIT_EXPORT_FILE, SUBJECT_EXPORT_RUN_AT, VISIT_EXPORT_RUN_AT
from web.smash_email import EmailSender
from .exporter import SubjectExporter, VisitExporter

logger = logging.getLogger(__name__)


class SubjectExporterCronJob(CronJobBase):
    item = ConfigurationItem.objects.filter(type=SUBJECT_EXPORT_RUN_AT).first()
    RUN_AT_TIMES = []
    if item is not None:
        RUN_AT_TIMES = item.value.split(';')
    schedule = Schedule(run_at_times=RUN_AT_TIMES)
    code = 'web.export_subject_daily_job'  # a unique code

    @timeout_decorator.timeout(CRON_JOB_TIMEOUT)
    def do(self):
        email_title = "Daily subject export"
        email_recipients = ConfigurationItem.objects.get(type=DEFAULT_FROM_EMAIL).value

        filename = ConfigurationItem.objects.get(type=DAILY_SUBJECT_EXPORT_FILE).value

        if filename is None or filename == '':
            logger.info("Exporting subjects skipped. File not defined ")
            return "export file not defined"
        logger.info("Exporting subjects to file: " + filename)
        try:
            exporter = SubjectExporter(filename)
            exporter.execute()
            email_body = exporter.get_summary()
            EmailSender().send_email(email_title,
                                     "<h3>Data was successfully exported to file: " + filename + "</h3>" + email_body,
                                     email_recipients)
            return "export is successful"

        except:
            tb = traceback.format_exc()
            EmailSender().send_email(email_title,
                                     "<h3><font color='red'>There was a problem with exporting data to file: " + filename + "</font></h3><pre>" + tb + "</pre>",
                                     email_recipients)
            return "export crashed"


class VisitExporterCronJob(CronJobBase):
    item = ConfigurationItem.objects.filter(type=VISIT_EXPORT_RUN_AT).first()
    RUN_AT_TIMES = []
    if item is not None:
        RUN_AT_TIMES = item.value.split(';')
    schedule = Schedule(run_at_times=RUN_AT_TIMES)
    code = 'web.export_visit_daily_job'  # a unique code

    @timeout_decorator.timeout(CRON_JOB_TIMEOUT)
    def do(self):
        email_title = "Daily visit export"
        email_recipients = ConfigurationItem.objects.get(type=DEFAULT_FROM_EMAIL).value

        filename = ConfigurationItem.objects.get(type=DAILY_VISIT_EXPORT_FILE).value

        if filename is None or filename == '':
            logger.info("Exporting visit skipped. File not defined ")
            return "export file not defined"
        logger.info("Exporting visits to file: " + filename)
        try:
            exporter = VisitExporter(filename)
            exporter.execute()
            email_body = exporter.get_summary()
            EmailSender().send_email(email_title,
                                     "<h3>Data was successfully exported to file: " + filename + "</h3>" + email_body,
                                     email_recipients)
            return "export is successful"

        except:
            tb = traceback.format_exc()
            EmailSender().send_email(email_title,
                                     "<h3><font color='red'>There was a problem with exporting data to file: " + filename + "</font></h3><pre>" + tb + "</pre>",
                                     email_recipients)
            return "export crashed"
