# coding=utf-8

import logging
import tempfile

from django.core import mail
from django.test import TestCase
from django_cron.models import CronJobLog

from web.importer import SubjectExporterCronJob
from web.models import ConfigurationItem
from web.models.constants import DAILY_SUBJECT_EXPORT_FILE

logger = logging.getLogger(__name__)


class TestCronJobExporter(TestCase):

    def test_import_without_configuration(self):
        CronJobLog.objects.all().delete()

        job = SubjectExporterCronJob()

        status = job.do()

        self.assertEqual("export file not defined", status)
        self.assertEqual(0, len(mail.outbox))

    def test_import(self):
        new_file, tmp = tempfile.mkstemp()

        item = ConfigurationItem.objects.get(type=DAILY_SUBJECT_EXPORT_FILE)
        item.value = tmp
        item.save()

        CronJobLog.objects.all().delete()

        job = SubjectExporterCronJob()

        status = job.do()

        self.assertEqual("export is successful", status)
        self.assertEqual(1, len(mail.outbox))
