# coding=utf-8

import logging
import tempfile
from shutil import copyfile

from django.core import mail
from django.test import TestCase
from django_cron.models import CronJobLog

from web.importer import SubjectImporterCronJob
from web.models import ConfigurationItem
from web.models.constants import DAILY_SUBJECT_IMPORT_FILE
from web.tests.functions import get_resource_path

logger = logging.getLogger(__name__)


class TestCronJobImporter(TestCase):

    def test_import_without_configuration(self):
        CronJobLog.objects.all().delete()

        job = SubjectImporterCronJob()

        status = job.do()

        self.assertEqual("import file not defined", status)
        self.assertEqual(0, len(mail.outbox))

    def test_import(self):
        filename = get_resource_path('tns_subjects_import.csv')
        new_file, tmp = tempfile.mkstemp()
        copyfile(filename, tmp)

        conf = ConfigurationItem.objects.get(type=DAILY_SUBJECT_IMPORT_FILE)
        conf.value = tmp
        conf.save()
        CronJobLog.objects.all().delete()

        job = SubjectImporterCronJob()

        status = job.do()

        self.assertEqual("import is successful", status)
        self.assertEqual(1, len(mail.outbox))
